// Persistence of Vision Ray Tracer Sample Scene File
// Part of the IRTC GIP object archives

// Demonstrating Object: IR_Canal
// Author: Ib Rasmussen
// Date (yyyy-mm-dd): 2000.01.30

#include "colors.inc"
#include "stones1.inc"
#include "skies.inc"

#version 3.1;
global_settings { assumed_gamma 1.0 }

#declare R = seed(0);

/************************* Declarations ******************************/

/*--------------------- Camera and Lights ---------------------------*/

#declare CamX=00;
#declare CamY=450;
#declare CamZ=-100;

#declare TestCam=camera {
   location  < CamX, CamY, CamZ >
   angle 60
   look_at   <0, 150,  1000 >
}

#declare PointLight=light_source { <0, 0, 0>, colour White }
#declare CamLight=light_source { <0, 0, 0>, colour White*0.5 }


/*-------------------------- Textures -------------------------------*/

#declare T_Water=texture {
    pigment { CornflowerBlue filter 0.80 transmit 0.20}
    normal {
       waves 0.08
       frequency 300.0
       scale 50
    }
    finish { ambient 0.1 diffuse 0.1 reflection 0.8 }
}



/*------------------------- Objects ----------------------------------*/
#declare ShowDetail = 1;
#include "IR_Canal.inc"
   
/***************************** Scene *********************************/

/*--------------- Camera, Lights and Background ---------------------*/

camera { TestCam }

object { PointLight translate < 1500, 1550, -800> }
object { PointLight translate <1500, 1550, -800> }
object { CamLight translate <CamX, CamY, CamZ> }

sky_sphere { S_Cloud1 }

/*------------------------- Objects ----------------------------------*/

#declare Water_Level = -60;

difference {
   plane { y, 0 translate <0, 150, 0> }
   box { <-430, -400, -400>, <430, 400, 10000> }
   pigment { Tan }
}
   
plane { y, 0 texture { T_Water } translate <0, Water_Level, 0>}
plane { y, 0 translate <0, Water_Level-1, 0> texture { pigment { Black } } }

object { IR_Canal(800, 10000, 150, Water_Level) rotate <0, -90, 0> }
